@@ -30,7 +30,7 @@
 
 class LameSettings : public LameConfig
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	LameSettings( TQWidget *parent, TDEConfig *confile );
@@ -48,7 +48,7 @@ private:
 
 class KLameEnc : public KaffeineAudioEncoder
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
