@@ -45,7 +45,7 @@
 MSpinBox::MSpinBox( TQWidget *parent, int devNum ) : TQSpinBox( 1, 4, 1, parent )
 {
 	deviceNumber = devNum;
-	connect( this, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(slotValueChanged(int)) );
+	connect( this, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(slotValueChanged(int)) );
 }
 
 
@@ -61,7 +61,7 @@ MPushButton::MPushButton( TQWidget *parent, int devNum, int lnbNum ) : KPushButt
 {
 	deviceNumber = devNum;
 	lnbNumber = lnbNum;
-	connect( this, TQT_SIGNAL(clicked()), this, TQT_SLOT(isClicked()) );
+	connect( this, TQ_SIGNAL(clicked()), this, TQ_SLOT(isClicked()) );
 }
 
 
@@ -76,7 +76,7 @@ void MPushButton::isClicked()
 MCAMButton::MCAMButton( TQWidget *parent, int devNum ) : TQPushButton( i18n("CAM"), parent )
 {
 	deviceNumber = devNum;
-	connect( this, TQT_SIGNAL(clicked()), this, TQT_SLOT(isClicked()) );
+	connect( this, TQ_SIGNAL(clicked()), this, TQ_SLOT(isClicked()) );
 }
 
 
@@ -92,7 +92,7 @@ MComboBox::MComboBox( TQWidget *parent, int devNum, int lnbNum ) : TQComboBox( p
 {
 	deviceNumber = devNum;
 	lnbNumber = lnbNum;
-	connect( this, TQT_SIGNAL(activated(int)), this, TQT_SLOT(isActivated(int)) );
+	connect( this, TQ_SIGNAL(activated(int)), this, TQ_SLOT(isActivated(int)) );
 }
 
 
@@ -286,11 +286,11 @@ bool DVBconfig::loadDvbData( TQWidget *parent )
 	downProgress->progressBar()->setTotalSteps( 100 );
 	//job = file_copy( KURL( "http://hftom.free.fr/kaxtv/dvbdata.tar.gz" ), KURL( dvbConfigDir+"dvbdata.tar.gz" ), -1, true, false, false );
 	job = file_copy( KURL( "http://hftom.free.fr/kaxtv/dvbdata.tar.gz" ), KURL( dvbConfigDir+"dvbdata.tar.gz" ), -1, true, false, false );
-	connect( job, TQT_SIGNAL(result(TDEIO::Job*)), this, TQT_SLOT(setDownloadResult(TDEIO::Job*)) );
-	connect( job, TQT_SIGNAL(percent(TDEIO::Job*,unsigned long)), this, TQT_SLOT(setDownloadPercent(TDEIO::Job*,unsigned long)) );
+	connect( job, TQ_SIGNAL(result(TDEIO::Job*)), this, TQ_SLOT(setDownloadResult(TDEIO::Job*)) );
+	connect( job, TQ_SIGNAL(percent(TDEIO::Job*,unsigned long)), this, TQ_SLOT(setDownloadPercent(TDEIO::Job*,unsigned long)) );
 	downProgress->exec();
-	disconnect( job, TQT_SIGNAL(result(TDEIO::Job*)), this, TQT_SLOT(setDownloadResult(TDEIO::Job*)) );
-	disconnect( job, TQT_SIGNAL(percent(TDEIO::Job*,unsigned long)), this, TQT_SLOT(setDownloadPercent(TDEIO::Job*,unsigned long)) );
+	disconnect( job, TQ_SIGNAL(result(TDEIO::Job*)), this, TQ_SLOT(setDownloadResult(TDEIO::Job*)) );
+	disconnect( job, TQ_SIGNAL(percent(TDEIO::Job*,unsigned long)), this, TQ_SLOT(setDownloadPercent(TDEIO::Job*,unsigned long)) );
 	if ( downProgress ) {
 		delete downProgress;
 		downProgress = 0;
@@ -615,7 +615,7 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 		if ( dvbConfig->devList.at(i)->hasCAM ) {
 			grid->addWidget( dvbType, gridLine, 1 );
 			MCAMButton *camb = new MCAMButton( gb, i );
-			connect( camb, TQT_SIGNAL(clicked(int)), pan, TQT_SLOT(camClicked(int)) );
+			connect( camb, TQ_SIGNAL(clicked(int)), pan, TQ_SLOT(camClicked(int)) );
 			grid->addWidget( camb, gridLine, 2 );
 		}
 		else
@@ -649,11 +649,11 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 			lab = new TQLabel( i18n("Number of LNBs:"), gb );
 			grid->addWidget( lab, gridLine, 0 );
 			satNumber[i] = new MSpinBox( gb, i );
-			connect( satNumber[i], TQT_SIGNAL(signalValueChanged(int,int)), this, TQT_SLOT(satNumberChanged(int,int)));
+			connect( satNumber[i], TQ_SIGNAL(signalValueChanged(int,int)), this, TQ_SLOT(satNumberChanged(int,int)));
 			grid->addWidget( satNumber[i], gridLine, 1 );
 			usals = new KPushButton( gb );
 			usals->setGuiItem( KGuiItem(i18n("Set rotor coordinates..."), icon->loadIconSet("move", TDEIcon::Small) ) );
-			connect( usals, TQT_SIGNAL(clicked()), this, TQT_SLOT(setUsals()));
+			connect( usals, TQ_SIGNAL(clicked()), this, TQ_SLOT(setUsals()));
 			grid->addWidget( usals, gridLine, 2 );
 
 			++gridLine;
@@ -672,12 +672,12 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 			lnb0[i]->setGuiItem( KGuiItem(i18n("LNB 1 settings..."), icon->loadIconSet("hwinfo", TDEIcon::Small) ) );
 			lnb0[i]->setEnabled(true);
 			grid->addWidget( lnb0[i], gridLine, 0 );
-			connect( lnb0[i], TQT_SIGNAL(clicked(int,int)), this, TQT_SLOT(setLnb(int,int)));
+			connect( lnb0[i], TQ_SIGNAL(clicked(int,int)), this, TQ_SLOT(setLnb(int,int)));
 			rotor0[i] = new MComboBox( gb, i, 0 );
 			rotor0[i]->insertStringList( rotorList );
 			rotor0[i]->setCurrentItem( dvbConfig->devList.at(i)->lnb[0].rotorType );
 			grid->addWidget( rotor0[i], gridLine, 1 );
-			connect( rotor0[i], TQT_SIGNAL(activated(int,int,int)), this, TQT_SLOT(setRotor(int,int,int)));
+			connect( rotor0[i], TQ_SIGNAL(activated(int,int,int)), this, TQ_SLOT(setRotor(int,int,int)));
 			swidg = new TQWidget( gb );
 			sgrid = new TQGridLayout( swidg, 1, 1, 0, 0 );
 			sat0[i] = new TQComboBox( swidg );
@@ -685,7 +685,7 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 			sgrid->addWidget( sat0[i], 0, 0 );
 			src0[i] = new MPushButton( swidg, i, 0 );
 			src0[i]->setGuiItem( KGuiItem(i18n("Sources list...") ) );
-			connect( src0[i], TQT_SIGNAL(clicked(int,int)), this, TQT_SLOT(setRotorSources(int,int)) );
+			connect( src0[i], TQ_SIGNAL(clicked(int,int)), this, TQ_SLOT(setRotorSources(int,int)) );
 			sgrid->addWidget( src0[i], 1, 0 );
 			if ( dvbConfig->devList.at(i)->lnb[0].rotorType==0 ) {
 				setSource( sat0[i], dvbConfig->devList.at(i)->lnb[0].source[0] );
@@ -701,13 +701,13 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 			lnb1[i]->setGuiItem( KGuiItem(i18n("LNB 2 settings..."), icon->loadIconSet("hwinfo", TDEIcon::Small) ) );
 			lnb1[i]->setEnabled(false);
 			grid->addWidget( lnb1[i], gridLine, 0 );
-			connect( lnb1[i], TQT_SIGNAL(clicked(int,int)), this, TQT_SLOT(setLnb(int,int)));
+			connect( lnb1[i], TQ_SIGNAL(clicked(int,int)), this, TQ_SLOT(setLnb(int,int)));
 			rotor1[i] = new MComboBox( gb, i, 1 );
 			rotor1[i]->setEnabled( false );
 			rotor1[i]->insertStringList( rotorList );
 			rotor1[i]->setCurrentItem( dvbConfig->devList.at(i)->lnb[1].rotorType );
 			grid->addWidget( rotor1[i], gridLine, 1 );
-			connect( rotor1[i], TQT_SIGNAL(activated(int,int,int)), this, TQT_SLOT(setRotor(int,int,int)));
+			connect( rotor1[i], TQ_SIGNAL(activated(int,int,int)), this, TQ_SLOT(setRotor(int,int,int)));
 			swidg = new TQWidget( gb );
 			sgrid = new TQGridLayout( swidg, 1, 1, 0, 0 );
 			sat1[i] = new TQComboBox( swidg );
@@ -717,7 +717,7 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 			src1[i] = new MPushButton( swidg, i, 1 );
 			src1[i]->setEnabled(false);
 			src1[i]->setGuiItem( KGuiItem(i18n("Sources list...") ) );
-			connect( src1[i], TQT_SIGNAL(clicked(int,int)), this, TQT_SLOT(setRotorSources(int,int)) );
+			connect( src1[i], TQ_SIGNAL(clicked(int,int)), this, TQ_SLOT(setRotorSources(int,int)) );
 			sgrid->addWidget( src1[i], 1, 0 );
 			if ( dvbConfig->devList.at(i)->lnb[1].rotorType==0 ) {
 				setSource( sat1[i], dvbConfig->devList.at(i)->lnb[1].source[0] );
@@ -733,13 +733,13 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 			lnb2[i]->setGuiItem( KGuiItem(i18n("LNB 3 settings..."), icon->loadIconSet("hwinfo", TDEIcon::Small) ) );
 			lnb2[i]->setEnabled(false);
 			grid->addWidget( lnb2[i], gridLine, 0 );
-			connect( lnb2[i], TQT_SIGNAL(clicked(int,int)), this, TQT_SLOT(setLnb(int,int)));
+			connect( lnb2[i], TQ_SIGNAL(clicked(int,int)), this, TQ_SLOT(setLnb(int,int)));
 			rotor2[i] = new MComboBox( gb, i, 2 );
 			rotor2[i]->setEnabled(false);
 			rotor2[i]->insertStringList( rotorList );
 			rotor2[i]->setCurrentItem( dvbConfig->devList.at(i)->lnb[2].rotorType );
 			grid->addWidget( rotor2[i], gridLine, 1 );
-			connect( rotor2[i], TQT_SIGNAL(activated(int,int,int)), this, TQT_SLOT(setRotor(int,int,int)));
+			connect( rotor2[i], TQ_SIGNAL(activated(int,int,int)), this, TQ_SLOT(setRotor(int,int,int)));
 			swidg = new TQWidget( gb );
 			sgrid = new TQGridLayout( swidg, 1, 1, 0, 0 );
 			sat2[i] = new TQComboBox( swidg );
@@ -749,7 +749,7 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 			src2[i] = new MPushButton( swidg, i, 2 );
 			src2[i]->setEnabled(false);
 			src2[i]->setGuiItem( KGuiItem(i18n("Sources list...") ) );
-			connect( src2[i], TQT_SIGNAL(clicked(int,int)), this, TQT_SLOT(setRotorSources(int,int)) );
+			connect( src2[i], TQ_SIGNAL(clicked(int,int)), this, TQ_SLOT(setRotorSources(int,int)) );
 			sgrid->addWidget( src2[i], 1, 0 );
 			if ( dvbConfig->devList.at(i)->lnb[2].rotorType==0 ) {
 				setSource( sat2[i], dvbConfig->devList.at(i)->lnb[2].source[0] );
@@ -765,13 +765,13 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 			lnb3[i]->setGuiItem( KGuiItem(i18n("LNB 4 settings..."), icon->loadIconSet("hwinfo", TDEIcon::Small) ) );
 			lnb3[i]->setEnabled(false);
 			grid->addWidget( lnb3[i], gridLine, 0 );
-			connect( lnb3[i], TQT_SIGNAL(clicked(int,int)), this, TQT_SLOT(setLnb(int,int)));
+			connect( lnb3[i], TQ_SIGNAL(clicked(int,int)), this, TQ_SLOT(setLnb(int,int)));
 			rotor3[i] = new MComboBox( gb, i, 3 );
 			rotor3[i]->setEnabled(false);
 			rotor3[i]->insertStringList( rotorList );
 			rotor3[i]->setCurrentItem( dvbConfig->devList.at(i)->lnb[3].rotorType );
 			grid->addWidget( rotor3[i], gridLine, 1 );
-			connect( rotor3[i], TQT_SIGNAL(activated(int,int,int)), this, TQT_SLOT(setRotor(int,int,int)));
+			connect( rotor3[i], TQ_SIGNAL(activated(int,int,int)), this, TQ_SLOT(setRotor(int,int,int)));
 			swidg = new TQWidget( gb );
 			sgrid = new TQGridLayout( swidg, 1, 1, 0, 0 );
 			sat3[i] = new TQComboBox( swidg );
@@ -781,7 +781,7 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 			src3[i] = new MPushButton( swidg, i, 3 );
 			src3[i]->setEnabled(false);
 			src3[i]->setGuiItem( KGuiItem(i18n("Sources list...") ) );
-			connect( src3[i], TQT_SIGNAL(clicked(int,int)), this, TQT_SLOT(setRotorSources(int,int)) );
+			connect( src3[i], TQ_SIGNAL(clicked(int,int)), this, TQ_SLOT(setRotorSources(int,int)) );
 			sgrid->addWidget( src3[i], 1, 0 );
 			if ( dvbConfig->devList.at(i)->lnb[3].rotorType==0 ) {
 				setSource( sat3[i], dvbConfig->devList.at(i)->lnb[3].source[0] );
@@ -983,15 +983,15 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 
 		KPushButton *btn = new KPushButton( p->pluginName(), gb );
 		grid->addWidget( btn, 0, 0 );
-		connect( btn, TQT_SIGNAL(clicked()), p, TQT_SLOT(configDialog()) );
+		connect( btn, TQ_SIGNAL(clicked()), p, TQ_SLOT(configDialog()) );
 		vb->addWidget( gb );
 		vb->addItem( new TQSpacerItem( 20, 20, TQSizePolicy::Ignored, TQSizePolicy::Ignored ) );
 	}
 
-	connect( recordDirBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(setRecordDir()) );
-	connect( shiftDirBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(setShiftDir()) );
-	connect( updateBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(downloadData()) );
-	connect( helpNameBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(fileTemplateHelp()) );
+	connect( recordDirBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(setRecordDir()) );
+	connect( shiftDirBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(setShiftDir()) );
+	connect( updateBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(downloadData()) );
+	connect( helpNameBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(fileTemplateHelp()) );
 	delete icon;
 }
 
@@ -1283,18 +1283,18 @@ LnbConfig::LnbConfig( LNB *b, TQWidget *parent ) :
 
 	TQVBoxLayout *vb = new TQVBoxLayout( page, 6, 6 );
 	univ = new TQPushButton( i18n("Universal LNB"), page );
-	connect( univ, TQT_SIGNAL(clicked()), this, TQT_SLOT(setUniversal()) );
+	connect( univ, TQ_SIGNAL(clicked()), this, TQ_SLOT(setUniversal()) );
 	vb->addWidget( univ );
 	cmono = new TQPushButton( i18n("C-Band LNB"), page );
-	connect( cmono, TQT_SIGNAL(clicked()), this, TQT_SLOT(setCBandMono()) );
+	connect( cmono, TQ_SIGNAL(clicked()), this, TQ_SLOT(setCBandMono()) );
 	vb->addWidget( cmono );
 	cmulti = new TQPushButton( i18n("C-Band Multipoint LNB"), page );
-	connect( cmulti, TQT_SIGNAL(clicked()), this, TQT_SLOT(setCBandMulti()) );
+	connect( cmulti, TQ_SIGNAL(clicked()), this, TQ_SLOT(setCBandMulti()) );
 	vb->addWidget( cmulti );
 
 	grid = new TQGridLayout( 0, 1, 1 );
-	nLO = new TQButtonGroup( 3, Qt::Horizontal, page );
-	connect( nLO, TQT_SIGNAL(clicked(int)), this, TQT_SLOT(setDual(int)) );
+	nLO = new TQButtonGroup( 3, TQt::Horizontal, page );
+	connect( nLO, TQ_SIGNAL(clicked(int)), this, TQ_SLOT(setDual(int)) );
 	new TQRadioButton( i18n("Dual LO"), nLO );
 	new TQRadioButton( i18n("Single LO"), nLO );
 	new TQRadioButton( i18n("H/V LO"), nLO );
@@ -1492,7 +1492,7 @@ RotorConfig::RotorConfig( Device *d, DVBconfig *c, int lnb, TQWidget *parent ) :
 	vb->addItem( new TQSpacerItem( 20, 10, TQSizePolicy::Fixed, TQSizePolicy::Fixed ) );
 
 	addBtn = new TQPushButton( i18n("Add to list"), page );
-	connect( addBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(add()) );
+	connect( addBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(add()) );
 	vb->addWidget( addBtn );
 	vb->addItem( new TQSpacerItem( 20, 10, TQSizePolicy::Fixed, TQSizePolicy::Fixed ) );
 
@@ -1501,7 +1501,7 @@ RotorConfig::RotorConfig( Device *d, DVBconfig *c, int lnb, TQWidget *parent ) :
 	vb->addWidget( listView );
 
 	resetBtn = new TQPushButton( i18n("Clear list"), page );
-	connect( resetBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(reset()) );
+	connect( resetBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(reset()) );
 	vb->addWidget( resetBtn );
 	vb->addItem( new TQSpacerItem( 20, 20, TQSizePolicy::Fixed, TQSizePolicy::Fixed ) );
 
