@@ -37,7 +37,7 @@
 
 class KTimerEditor : public TQDialog
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
