@@ -40,45 +40,45 @@ VideoSettings::VideoSettings(int hue, int sat, int contr, int bright, TQWidget *
 
   TQLabel* hueText = new TQLabel(i18n("Hue"), page);
   hueText->setAlignment(AlignRight);
-  m_hueSlider = new TQSlider(Qt::Horizontal, page);
+  m_hueSlider = new TQSlider(TQt::Horizontal, page);
   m_hueSlider->setRange(-1000, 1000);
   m_hueSlider->setSteps(10, 100);
   m_hueSlider->setValue(hue);
-  connect(m_hueSlider, TQT_SIGNAL(valueChanged(int)), this, TQT_SIGNAL(signalNewHue(int)));
+  connect(m_hueSlider, TQ_SIGNAL(valueChanged(int)), this, TQ_SIGNAL(signalNewHue(int)));
   grid->addWidget(hueText, 0, 0);
   grid->addWidget(m_hueSlider, 0, 1);
 
   TQLabel* satText = new TQLabel(i18n("Saturation"), page);
   satText->setAlignment(AlignRight);
-  m_satSlider = new TQSlider(Qt::Horizontal, page);
+  m_satSlider = new TQSlider(TQt::Horizontal, page);
   m_satSlider->setRange(-1000, 1000);
   m_satSlider->setSteps(10, 100);
   m_satSlider->setValue(sat);
-  connect(m_satSlider, TQT_SIGNAL(valueChanged(int)), this, TQT_SIGNAL(signalNewSaturation(int)));
+  connect(m_satSlider, TQ_SIGNAL(valueChanged(int)), this, TQ_SIGNAL(signalNewSaturation(int)));
   grid->addWidget(satText, 1, 0);
   grid->addWidget(m_satSlider, 1, 1);
 
   TQLabel* contrastText = new TQLabel(i18n("Contrast"), page);
   contrastText->setAlignment(AlignRight);
-  m_contrastSlider = new TQSlider(Qt::Horizontal, page);
+  m_contrastSlider = new TQSlider(TQt::Horizontal, page);
   m_contrastSlider->setRange(-1000, 1000);
   m_contrastSlider->setSteps(10, 100);
   m_contrastSlider->setValue(contr);
-  connect(m_contrastSlider, TQT_SIGNAL(valueChanged(int)), this, TQT_SIGNAL(signalNewContrast(int)));
+  connect(m_contrastSlider, TQ_SIGNAL(valueChanged(int)), this, TQ_SIGNAL(signalNewContrast(int)));
   grid->addWidget(contrastText, 2, 0);
   grid->addWidget(m_contrastSlider, 2, 1);
 
   TQLabel* brightText = new TQLabel(i18n("Brightness"), page);
   brightText->setAlignment(AlignRight);
-  m_brightSlider = new TQSlider(Qt::Horizontal, page);
+  m_brightSlider = new TQSlider(TQt::Horizontal, page);
   m_brightSlider->setRange(-1000, 1000);
   m_brightSlider->setSteps(10, 100);
   m_brightSlider->setValue(bright);
-  connect(m_brightSlider, TQT_SIGNAL(valueChanged(int)), this, TQT_SIGNAL(signalNewBrightness(int)));
+  connect(m_brightSlider, TQ_SIGNAL(valueChanged(int)), this, TQ_SIGNAL(signalNewBrightness(int)));
   grid->addWidget(brightText, 3, 0);
   grid->addWidget(m_brightSlider, 3, 1);
 
-  connect(this, TQT_SIGNAL(defaultClicked()), this, TQT_SLOT(slotSetDefaultValues()));
+  connect(this, TQ_SIGNAL(defaultClicked()), this, TQ_SLOT(slotSetDefaultValues()));
 }
 
 VideoSettings::~VideoSettings()
