@@ -39,7 +39,7 @@ class TQGridLayout;
 /* stores a single config entry of the config file */
 class XineConfigEntry : public TQHBox
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	XineConfigEntry(TQWidget* parent, TQGridLayout* grid, int row, xine_cfg_entry_t* entry);
@@ -76,7 +76,7 @@ private:
 
 class XineConfig : public KDialogBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	XineConfig(const xine_t* const xine);
